:py:mod:`pytomography.io.PET.prd._dtypes`
=========================================

.. py:module:: pytomography.io.PET.prd._dtypes


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   pytomography.io.PET.prd._dtypes.make_get_dtype_func



.. py:function:: make_get_dtype_func(dtype_map)


